@@ -39,12 +39,7 @@
  *                                                                           *
  * ========================================================================= */
 
-/*===========================================================================*\
- *                                                                           *             
- *   $Revision: 1258 $                                                         *
- *   $Date: 2015-04-28 15:07:46 +0200 (Di, 28 Apr 2015) $                   *
- *                                                                           *
-\*===========================================================================*/
+
 
 #ifndef DOXY_IGNORE_THIS
 // ----------------------------------------------------------------------------
@@ -88,7 +83,7 @@ public:
 // compiler and os dependent implementation
 
 // ------------------------------------------------------------- windows 32 ----
-#if defined(WIN32) && (defined(_MSC_VER) || defined(__INTEL_COMPILER))
+#if defined(WIN32) && (defined(_MSC_VER) || defined(__INTEL_COMPILER) || defined (__MINGW32__) )
 
 #ifndef DOXY_IGNORE_THIS
 #include <windows.h>
@@ -261,9 +256,10 @@ void TimerImplStd::stop(void)
 
 // ----------------------------------------------------------------- Timer ----
 
-Timer::Timer(void)
+Timer::Timer(void) :
+    state_(Stopped)
 {
-#if defined(WIN32) && defined(_MSC_VER)
+#if defined(WIN32) && (defined(_MSC_VER) || defined(__INTEL_COMPILER) || defined(__MINGW32__)) 
   impl_       = new TimerImplWin32;
 #elif defined(__GNUC__) && defined(__POSIX__)
 // CLOCK_REALTIME
@@ -280,7 +276,7 @@ Timer::Timer(void)
 #else
   impl_       = new TimerImplStd;
 #endif
-  state_      = Stopped;
+
 }
 
 Timer::~Timer(void)
